# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'IpRangeLink',
    'IpRangeTag',
    'NetworkConstraint',
    'NetworkLink',
    'NetworkTag',
    'ProfileLink',
    'ProfileTag',
    'GetDomainLinkResult',
    'GetDomainTagResult',
    'GetNetworkConstraintResult',
    'GetNetworkLinkResult',
    'GetNetworkTagResult',
    'GetProfileLinkResult',
    'GetProfileTagResult',
]

@pulumi.output_type
class IpRangeLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class IpRangeTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class NetworkConstraint(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class NetworkLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class NetworkTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class ProfileLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class ProfileTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetDomainLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetDomainTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetNetworkConstraintResult(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class GetNetworkLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetNetworkTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetProfileLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetProfileTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProfileArgs', 'Profile']

@pulumi.input_type
class ProfileArgs:
    def __init__(__self__, *,
                 region_id: pulumi.Input[str],
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 fabric_network_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 isolated_external_fabric_network_id: Optional[pulumi.Input[str]] = None,
                 isolated_network_cidr_prefix: Optional[pulumi.Input[int]] = None,
                 isolated_network_domain_cidr: Optional[pulumi.Input[str]] = None,
                 isolated_network_domain_id: Optional[pulumi.Input[str]] = None,
                 isolation_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]]] = None):
        """
        The set of arguments for constructing a Profile resource.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fabric_network_ids: A list of fabric network Ids which are assigned to the network profile.
               example:[ "6543" ]
        :param pulumi.Input[str] isolated_external_fabric_network_id: The id of the fabric network used for outbound access.
        :param pulumi.Input[int] isolated_network_cidr_prefix: The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        :param pulumi.Input[str] isolated_network_domain_cidr: CIDR of the isolation network domain.
        :param pulumi.Input[str] isolated_network_domain_id: The id of the network domain used for creating isolated networks.
        :param pulumi.Input[str] isolation_type: Specifies the isolation type e.g. none, subnet or security group
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: A list of security group Ids which are assigned to the network profile.
               example:[ "6545" ]
        :param pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        pulumi.set(__self__, "region_id", region_id)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if fabric_network_ids is not None:
            pulumi.set(__self__, "fabric_network_ids", fabric_network_ids)
        if isolated_external_fabric_network_id is not None:
            pulumi.set(__self__, "isolated_external_fabric_network_id", isolated_external_fabric_network_id)
        if isolated_network_cidr_prefix is not None:
            pulumi.set(__self__, "isolated_network_cidr_prefix", isolated_network_cidr_prefix)
        if isolated_network_domain_cidr is not None:
            pulumi.set(__self__, "isolated_network_domain_cidr", isolated_network_domain_cidr)
        if isolated_network_domain_id is not None:
            pulumi.set(__self__, "isolated_network_domain_id", isolated_network_domain_id)
        if isolation_type is not None:
            pulumi.set(__self__, "isolation_type", isolation_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Input[str]:
        """
        The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="fabricNetworkIds")
    def fabric_network_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of fabric network Ids which are assigned to the network profile.
        example:[ "6543" ]
        """
        return pulumi.get(self, "fabric_network_ids")

    @fabric_network_ids.setter
    def fabric_network_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "fabric_network_ids", value)

    @property
    @pulumi.getter(name="isolatedExternalFabricNetworkId")
    def isolated_external_fabric_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the fabric network used for outbound access.
        """
        return pulumi.get(self, "isolated_external_fabric_network_id")

    @isolated_external_fabric_network_id.setter
    def isolated_external_fabric_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolated_external_fabric_network_id", value)

    @property
    @pulumi.getter(name="isolatedNetworkCidrPrefix")
    def isolated_network_cidr_prefix(self) -> Optional[pulumi.Input[int]]:
        """
        The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        """
        return pulumi.get(self, "isolated_network_cidr_prefix")

    @isolated_network_cidr_prefix.setter
    def isolated_network_cidr_prefix(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "isolated_network_cidr_prefix", value)

    @property
    @pulumi.getter(name="isolatedNetworkDomainCidr")
    def isolated_network_domain_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        CIDR of the isolation network domain.
        """
        return pulumi.get(self, "isolated_network_domain_cidr")

    @isolated_network_domain_cidr.setter
    def isolated_network_domain_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolated_network_domain_cidr", value)

    @property
    @pulumi.getter(name="isolatedNetworkDomainId")
    def isolated_network_domain_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the network domain used for creating isolated networks.
        """
        return pulumi.get(self, "isolated_network_domain_id")

    @isolated_network_domain_id.setter
    def isolated_network_domain_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolated_network_domain_id", value)

    @property
    @pulumi.getter(name="isolationType")
    def isolation_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the isolation type e.g. none, subnet or security group
        """
        return pulumi.get(self, "isolation_type")

    @isolation_type.setter
    def isolation_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolation_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of security group Ids which are assigned to the network profile.
        example:[ "6545" ]
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ProfileState:
    def __init__(__self__, *,
                 cloud_account_id: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 fabric_network_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 isolated_external_fabric_network_id: Optional[pulumi.Input[str]] = None,
                 isolated_network_cidr_prefix: Optional[pulumi.Input[int]] = None,
                 isolated_network_domain_cidr: Optional[pulumi.Input[str]] = None,
                 isolated_network_domain_id: Optional[pulumi.Input[str]] = None,
                 isolation_type: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Profile resources.
        :param pulumi.Input[str] cloud_account_id: The ID of the cloud account this entity belongs to.
        :param pulumi.Input[str] created_at: Date when  entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_region_id: The external regionId of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fabric_network_ids: A list of fabric network Ids which are assigned to the network profile.
               example:[ "6543" ]
        :param pulumi.Input[str] isolated_external_fabric_network_id: The id of the fabric network used for outbound access.
        :param pulumi.Input[int] isolated_network_cidr_prefix: The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        :param pulumi.Input[str] isolated_network_domain_cidr: CIDR of the isolation network domain.
        :param pulumi.Input[str] isolated_network_domain_id: The id of the network domain used for creating isolated networks.
        :param pulumi.Input[str] isolation_type: Specifies the isolation type e.g. none, subnet or security group
        :param pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to. Deprecated, refer to org_id instead.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: A list of security group Ids which are assigned to the network profile.
               example:[ "6545" ]
        :param pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        if cloud_account_id is not None:
            pulumi.set(__self__, "cloud_account_id", cloud_account_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if fabric_network_ids is not None:
            pulumi.set(__self__, "fabric_network_ids", fabric_network_ids)
        if isolated_external_fabric_network_id is not None:
            pulumi.set(__self__, "isolated_external_fabric_network_id", isolated_external_fabric_network_id)
        if isolated_network_cidr_prefix is not None:
            pulumi.set(__self__, "isolated_network_cidr_prefix", isolated_network_cidr_prefix)
        if isolated_network_domain_cidr is not None:
            pulumi.set(__self__, "isolated_network_domain_cidr", isolated_network_domain_cidr)
        if isolated_network_domain_id is not None:
            pulumi.set(__self__, "isolated_network_domain_id", isolated_network_domain_id)
        if isolation_type is not None:
            pulumi.set(__self__, "isolation_type", isolation_type)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the cloud account this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_id")

    @cloud_account_id.setter
    def cloud_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloud_account_id", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when  entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter(name="fabricNetworkIds")
    def fabric_network_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of fabric network Ids which are assigned to the network profile.
        example:[ "6543" ]
        """
        return pulumi.get(self, "fabric_network_ids")

    @fabric_network_ids.setter
    def fabric_network_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "fabric_network_ids", value)

    @property
    @pulumi.getter(name="isolatedExternalFabricNetworkId")
    def isolated_external_fabric_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the fabric network used for outbound access.
        """
        return pulumi.get(self, "isolated_external_fabric_network_id")

    @isolated_external_fabric_network_id.setter
    def isolated_external_fabric_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolated_external_fabric_network_id", value)

    @property
    @pulumi.getter(name="isolatedNetworkCidrPrefix")
    def isolated_network_cidr_prefix(self) -> Optional[pulumi.Input[int]]:
        """
        The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        """
        return pulumi.get(self, "isolated_network_cidr_prefix")

    @isolated_network_cidr_prefix.setter
    def isolated_network_cidr_prefix(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "isolated_network_cidr_prefix", value)

    @property
    @pulumi.getter(name="isolatedNetworkDomainCidr")
    def isolated_network_domain_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        CIDR of the isolation network domain.
        """
        return pulumi.get(self, "isolated_network_domain_cidr")

    @isolated_network_domain_cidr.setter
    def isolated_network_domain_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolated_network_domain_cidr", value)

    @property
    @pulumi.getter(name="isolatedNetworkDomainId")
    def isolated_network_domain_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the network domain used for creating isolated networks.
        """
        return pulumi.get(self, "isolated_network_domain_id")

    @isolated_network_domain_id.setter
    def isolated_network_domain_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolated_network_domain_id", value)

    @property
    @pulumi.getter(name="isolationType")
    def isolation_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the isolation type e.g. none, subnet or security group
        """
        return pulumi.get(self, "isolation_type")

    @isolation_type.setter
    def isolation_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolation_type", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the organization this entity belongs to. Deprecated, refer to org_id instead.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of security group Ids which are assigned to the network profile.
        example:[ "6545" ]
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Profile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 fabric_network_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 isolated_external_fabric_network_id: Optional[pulumi.Input[str]] = None,
                 isolated_network_cidr_prefix: Optional[pulumi.Input[int]] = None,
                 isolated_network_domain_cidr: Optional[pulumi.Input[str]] = None,
                 isolated_network_domain_id: Optional[pulumi.Input[str]] = None,
                 isolation_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileTagArgs']]]]] = None,
                 __props__=None):
        """
        ## Example Usage
        ### S
        This is an example of how to create a network profile resource.

        **Network profile:**

        ```python
        import pulumi
        import pulumiverse_vra as vra

        simple = vra.network.Profile("simple",
            description="Simple Network Profile with no isolation.",
            region_id=data["vra_region"]["this"]["id"],
            fabric_network_ids=[
                data["vra_fabric_network"]["subnet_1"]["id"],
                data["vra_fabric_network"]["subnet_2"]["id"],
            ],
            isolation_type="NONE",
            tags=[vra.network.ProfileTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        A network profile resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fabric_network_ids: A list of fabric network Ids which are assigned to the network profile.
               example:[ "6543" ]
        :param pulumi.Input[str] isolated_external_fabric_network_id: The id of the fabric network used for outbound access.
        :param pulumi.Input[int] isolated_network_cidr_prefix: The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        :param pulumi.Input[str] isolated_network_domain_cidr: CIDR of the isolation network domain.
        :param pulumi.Input[str] isolated_network_domain_id: The id of the network domain used for creating isolated networks.
        :param pulumi.Input[str] isolation_type: Specifies the isolation type e.g. none, subnet or security group
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: A list of security group Ids which are assigned to the network profile.
               example:[ "6545" ]
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileTagArgs']]]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage
        ### S
        This is an example of how to create a network profile resource.

        **Network profile:**

        ```python
        import pulumi
        import pulumiverse_vra as vra

        simple = vra.network.Profile("simple",
            description="Simple Network Profile with no isolation.",
            region_id=data["vra_region"]["this"]["id"],
            fabric_network_ids=[
                data["vra_fabric_network"]["subnet_1"]["id"],
                data["vra_fabric_network"]["subnet_2"]["id"],
            ],
            isolation_type="NONE",
            tags=[vra.network.ProfileTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        A network profile resource supports the following arguments:

        :param str resource_name: The name of the resource.
        :param ProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 fabric_network_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 isolated_external_fabric_network_id: Optional[pulumi.Input[str]] = None,
                 isolated_network_cidr_prefix: Optional[pulumi.Input[int]] = None,
                 isolated_network_domain_cidr: Optional[pulumi.Input[str]] = None,
                 isolated_network_domain_id: Optional[pulumi.Input[str]] = None,
                 isolation_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileArgs.__new__(ProfileArgs)

            __props__.__dict__["custom_properties"] = custom_properties
            __props__.__dict__["description"] = description
            __props__.__dict__["fabric_network_ids"] = fabric_network_ids
            __props__.__dict__["isolated_external_fabric_network_id"] = isolated_external_fabric_network_id
            __props__.__dict__["isolated_network_cidr_prefix"] = isolated_network_cidr_prefix
            __props__.__dict__["isolated_network_domain_cidr"] = isolated_network_domain_cidr
            __props__.__dict__["isolated_network_domain_id"] = isolated_network_domain_id
            __props__.__dict__["isolation_type"] = isolation_type
            __props__.__dict__["name"] = name
            if region_id is None and not opts.urn:
                raise TypeError("Missing required property 'region_id'")
            __props__.__dict__["region_id"] = region_id
            __props__.__dict__["security_group_ids"] = security_group_ids
            __props__.__dict__["tags"] = tags
            __props__.__dict__["cloud_account_id"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(Profile, __self__).__init__(
            'vra:network/profile:Profile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_account_id: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            fabric_network_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            isolated_external_fabric_network_id: Optional[pulumi.Input[str]] = None,
            isolated_network_cidr_prefix: Optional[pulumi.Input[int]] = None,
            isolated_network_domain_cidr: Optional[pulumi.Input[str]] = None,
            isolated_network_domain_id: Optional[pulumi.Input[str]] = None,
            isolation_type: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            region_id: Optional[pulumi.Input[str]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Profile':
        """
        Get an existing Profile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cloud_account_id: The ID of the cloud account this entity belongs to.
        :param pulumi.Input[str] created_at: Date when  entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_region_id: The external regionId of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fabric_network_ids: A list of fabric network Ids which are assigned to the network profile.
               example:[ "6543" ]
        :param pulumi.Input[str] isolated_external_fabric_network_id: The id of the fabric network used for outbound access.
        :param pulumi.Input[int] isolated_network_cidr_prefix: The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        :param pulumi.Input[str] isolated_network_domain_cidr: CIDR of the isolation network domain.
        :param pulumi.Input[str] isolated_network_domain_id: The id of the network domain used for creating isolated networks.
        :param pulumi.Input[str] isolation_type: Specifies the isolation type e.g. none, subnet or security group
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] organization_id: The id of the organization this entity belongs to. Deprecated, refer to org_id instead.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[str] region_id: The id of the region for which this profile is defined as in vRealize Automation(vRA).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: A list of security group Ids which are assigned to the network profile.
               example:[ "6545" ]
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProfileTagArgs']]]] tags: A set of tag keys and optional values that were set on this Network Profile.
               example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileState.__new__(_ProfileState)

        __props__.__dict__["cloud_account_id"] = cloud_account_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["description"] = description
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["fabric_network_ids"] = fabric_network_ids
        __props__.__dict__["isolated_external_fabric_network_id"] = isolated_external_fabric_network_id
        __props__.__dict__["isolated_network_cidr_prefix"] = isolated_network_cidr_prefix
        __props__.__dict__["isolated_network_domain_cidr"] = isolated_network_domain_cidr
        __props__.__dict__["isolated_network_domain_id"] = isolated_network_domain_id
        __props__.__dict__["isolation_type"] = isolation_type
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return Profile(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> pulumi.Output[str]:
        """
        The ID of the cloud account this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when  entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="fabricNetworkIds")
    def fabric_network_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of fabric network Ids which are assigned to the network profile.
        example:[ "6543" ]
        """
        return pulumi.get(self, "fabric_network_ids")

    @property
    @pulumi.getter(name="isolatedExternalFabricNetworkId")
    def isolated_external_fabric_network_id(self) -> pulumi.Output[Optional[str]]:
        """
        The id of the fabric network used for outbound access.
        """
        return pulumi.get(self, "isolated_external_fabric_network_id")

    @property
    @pulumi.getter(name="isolatedNetworkCidrPrefix")
    def isolated_network_cidr_prefix(self) -> pulumi.Output[Optional[int]]:
        """
        The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        """
        return pulumi.get(self, "isolated_network_cidr_prefix")

    @property
    @pulumi.getter(name="isolatedNetworkDomainCidr")
    def isolated_network_domain_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        CIDR of the isolation network domain.
        """
        return pulumi.get(self, "isolated_network_domain_cidr")

    @property
    @pulumi.getter(name="isolatedNetworkDomainId")
    def isolated_network_domain_id(self) -> pulumi.Output[Optional[str]]:
        """
        The id of the network domain used for creating isolated networks.
        """
        return pulumi.get(self, "isolated_network_domain_id")

    @property
    @pulumi.getter(name="isolationType")
    def isolation_type(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the isolation type e.g. none, subnet or security group
        """
        return pulumi.get(self, "isolation_type")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.ProfileLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        The id of the organization this entity belongs to. Deprecated, refer to org_id instead.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[str]:
        """
        The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of security group Ids which are assigned to the network profile.
        example:[ "6545" ]
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ProfileTag']]:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'IpRangeLinkArgs',
    'IpRangeTagArgs',
    'NetworkConstraintArgs',
    'NetworkLinkArgs',
    'NetworkTagArgs',
    'ProfileLinkArgs',
    'ProfileTagArgs',
    'GetDomainTagArgs',
    'GetNetworkConstraintArgs',
    'GetNetworkTagArgs',
    'GetProfileTagArgs',
]

@pulumi.input_type
class IpRangeLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class IpRangeTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class NetworkConstraintArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 mandatory: pulumi.Input[bool]):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: pulumi.Input[bool]):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class NetworkLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class NetworkTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class ProfileLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class ProfileTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetDomainTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetNetworkConstraintArgs:
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: str):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: bool):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class GetNetworkTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetProfileTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ItemEntitlementDefinitionArgs',
    'SourceEntitlementDefinitionArgs',
]

@pulumi.input_type
class ItemEntitlementDefinitionArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 icon_id: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 number_of_items: Optional[pulumi.Input[int]] = None,
                 source_name: Optional[pulumi.Input[str]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] description: Description of the catalog item.
        :param pulumi.Input[str] icon_id: Icon id of associated catalog item.
        :param pulumi.Input[str] id: Id of the catalog item.
        :param pulumi.Input[str] name: Name of the catalog item.
        :param pulumi.Input[int] number_of_items: Number of items in the associated catalog source.
        :param pulumi.Input[str] source_name: Catalog source name.
        :param pulumi.Input[str] source_type: Catalog source type.
        :param pulumi.Input[str] type: Content definition type.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if icon_id is not None:
            pulumi.set(__self__, "icon_id", icon_id)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if number_of_items is not None:
            pulumi.set(__self__, "number_of_items", number_of_items)
        if source_name is not None:
            pulumi.set(__self__, "source_name", source_name)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the catalog item.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="iconId")
    def icon_id(self) -> Optional[pulumi.Input[str]]:
        """
        Icon id of associated catalog item.
        """
        return pulumi.get(self, "icon_id")

    @icon_id.setter
    def icon_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icon_id", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the catalog item.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the catalog item.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="numberOfItems")
    def number_of_items(self) -> Optional[pulumi.Input[int]]:
        """
        Number of items in the associated catalog source.
        """
        return pulumi.get(self, "number_of_items")

    @number_of_items.setter
    def number_of_items(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "number_of_items", value)

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> Optional[pulumi.Input[str]]:
        """
        Catalog source name.
        """
        return pulumi.get(self, "source_name")

    @source_name.setter
    def source_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_name", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[str]]:
        """
        Catalog source type.
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Content definition type.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class SourceEntitlementDefinitionArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 icon_id: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 number_of_items: Optional[pulumi.Input[int]] = None,
                 source_name: Optional[pulumi.Input[str]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        if description is not None:
            pulumi.set(__self__, "description", description)
        if icon_id is not None:
            pulumi.set(__self__, "icon_id", icon_id)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if number_of_items is not None:
            pulumi.set(__self__, "number_of_items", number_of_items)
        if source_name is not None:
            pulumi.set(__self__, "source_name", source_name)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="iconId")
    def icon_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "icon_id")

    @icon_id.setter
    def icon_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icon_id", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="numberOfItems")
    def number_of_items(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "number_of_items")

    @number_of_items.setter
    def number_of_items(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "number_of_items", value)

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_name")

    @source_name.setter
    def source_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_name", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDomainResult',
    'AwaitableGetDomainResult',
    'get_domain',
    'get_domain_output',
]

@pulumi.output_type
class GetDomainResult:
    """
    A collection of values returned by getDomain.
    """
    def __init__(__self__, cidr=None, cloud_account_ids=None, created_at=None, custom_properties=None, description=None, external_id=None, external_region_id=None, filter=None, id=None, links=None, name=None, organization_id=None, owner=None, tags=None, updated_at=None):
        if cidr and not isinstance(cidr, str):
            raise TypeError("Expected argument 'cidr' to be a str")
        pulumi.set(__self__, "cidr", cidr)
        if cloud_account_ids and not isinstance(cloud_account_ids, list):
            raise TypeError("Expected argument 'cloud_account_ids' to be a list")
        pulumi.set(__self__, "cloud_account_ids", cloud_account_ids)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if custom_properties and not isinstance(custom_properties, dict):
            raise TypeError("Expected argument 'custom_properties' to be a dict")
        pulumi.set(__self__, "custom_properties", custom_properties)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def cidr(self) -> str:
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> Sequence[str]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Mapping[str, Any]:
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description of the fabric vSphere storage account.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The id of the region for which this entity is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def filter(self) -> str:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetDomainLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the network domain.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetDomainTagResult']:
        """
        Set of tag keys and values to apply to the resource.
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetDomainResult(GetDomainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainResult(
            cidr=self.cidr,
            cloud_account_ids=self.cloud_account_ids,
            created_at=self.created_at,
            custom_properties=self.custom_properties,
            description=self.description,
            external_id=self.external_id,
            external_region_id=self.external_region_id,
            filter=self.filter,
            id=self.id,
            links=self.links,
            name=self.name,
            organization_id=self.organization_id,
            owner=self.owner,
            tags=self.tags,
            updated_at=self.updated_at)


def get_domain(filter: Optional[str] = None,
               tags: Optional[Sequence[pulumi.InputType['GetDomainTagArgs']]] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainResult:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup Network domain objects.

    **Network Domain by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.network.get_domain(filter=f"name eq '{var['name']}'")
    ```

    A network domain object supports the following arguments:


    :param str filter: Search criteria to narrow down the network domain objects.
    :param Sequence[pulumi.InputType['GetDomainTagArgs']] tags: Set of tag keys and values to apply to the resource.
           Example:[ { "key" : "vmware", "value": "provider" } ]
    """
    __args__ = dict()
    __args__['filter'] = filter
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:network/getDomain:getDomain', __args__, opts=opts, typ=GetDomainResult).value

    return AwaitableGetDomainResult(
        cidr=__ret__.cidr,
        cloud_account_ids=__ret__.cloud_account_ids,
        created_at=__ret__.created_at,
        custom_properties=__ret__.custom_properties,
        description=__ret__.description,
        external_id=__ret__.external_id,
        external_region_id=__ret__.external_region_id,
        filter=__ret__.filter,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        organization_id=__ret__.organization_id,
        owner=__ret__.owner,
        tags=__ret__.tags,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_domain)
def get_domain_output(filter: Optional[pulumi.Input[str]] = None,
                      tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDomainTagArgs']]]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDomainResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup Network domain objects.

    **Network Domain by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.network.get_domain(filter=f"name eq '{var['name']}'")
    ```

    A network domain object supports the following arguments:


    :param str filter: Search criteria to narrow down the network domain objects.
    :param Sequence[pulumi.InputType['GetDomainTagArgs']] tags: Set of tag keys and values to apply to the resource.
           Example:[ { "key" : "vmware", "value": "provider" } ]
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetDataCollectorResult',
    'AwaitableGetDataCollectorResult',
    'get_data_collector',
    'get_data_collector_output',
]

@pulumi.output_type
class GetDataCollectorResult:
    """
    A collection of values returned by getDataCollector.
    """
    def __init__(__self__, hostname=None, id=None, ip_address=None, name=None, status=None):
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        pulumi.set(__self__, "ip_address", ip_address)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def hostname(self) -> str:
        """
        Data collector host name. Example: dc1-lnd.mycompany.com
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> str:
        """
        IPv4 Address of the data collector VM. Example: 10.0.0.1
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Current status of the data collector. Example: ACTIVE, INACTIVE
        """
        return pulumi.get(self, "status")


class AwaitableGetDataCollectorResult(GetDataCollectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataCollectorResult(
            hostname=self.hostname,
            id=self.id,
            ip_address=self.ip_address,
            name=self.name,
            status=self.status)


def get_data_collector(name: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataCollectorResult:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a data collector.

    **Data collector data source by its name:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.datacollector.get_data_collector(name=var["data_collector_name"])
    ```
    The data collector data source supports the following arguments:


    :param str name: Data collector name. Example: Datacollector1
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:datacollector/getDataCollector:getDataCollector', __args__, opts=opts, typ=GetDataCollectorResult).value

    return AwaitableGetDataCollectorResult(
        hostname=__ret__.hostname,
        id=__ret__.id,
        ip_address=__ret__.ip_address,
        name=__ret__.name,
        status=__ret__.status)


@_utilities.lift_output_func(get_data_collector)
def get_data_collector_output(name: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDataCollectorResult]:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a data collector.

    **Data collector data source by its name:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.datacollector.get_data_collector(name=var["data_collector_name"])
    ```
    The data collector data source supports the following arguments:


    :param str name: Data collector name. Example: Datacollector1
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetSourceEntitlementResult',
    'AwaitableGetSourceEntitlementResult',
    'get_source_entitlement',
    'get_source_entitlement_output',
]

@pulumi.output_type
class GetSourceEntitlementResult:
    """
    A collection of values returned by getSourceEntitlement.
    """
    def __init__(__self__, catalog_source_id=None, definitions=None, id=None, project_id=None):
        if catalog_source_id and not isinstance(catalog_source_id, str):
            raise TypeError("Expected argument 'catalog_source_id' to be a str")
        pulumi.set(__self__, "catalog_source_id", catalog_source_id)
        if definitions and not isinstance(definitions, list):
            raise TypeError("Expected argument 'definitions' to be a list")
        pulumi.set(__self__, "definitions", definitions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @property
    @pulumi.getter(name="catalogSourceId")
    def catalog_source_id(self) -> Optional[str]:
        return pulumi.get(self, "catalog_source_id")

    @property
    @pulumi.getter
    def definitions(self) -> Sequence['outputs.GetSourceEntitlementDefinitionResult']:
        """
        Represents a catalog source that is linked to a project via an entitlement.
        """
        return pulumi.get(self, "definitions")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Id of the catalog source.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        return pulumi.get(self, "project_id")


class AwaitableGetSourceEntitlementResult(GetSourceEntitlementResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSourceEntitlementResult(
            catalog_source_id=self.catalog_source_id,
            definitions=self.definitions,
            id=self.id,
            project_id=self.project_id)


def get_source_entitlement(catalog_source_id: Optional[str] = None,
                           id: Optional[str] = None,
                           project_id: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSourceEntitlementResult:
    """
    This data source provides information about a catalog source entitlement in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA catalog source entitlement by its id:

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_entitlement(id=var["catalog_source_entitlement_id"],
        project_id=var["project_id"])
    ```

    This is an example of how to get a vRA catalog source entitlement by its catalog source id:

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_entitlement(catalog_source_id=var["catalog_source_id"],
        project_id=var["project_id"])
    ```


    :param str catalog_source_id: The id of the catalog source to find the entitlement. One of `catalog_source_id` or `id` must be provided.
    :param str id: The id of entitlement. One of `catalog_source_id` or `id` must be provided.
    :param str project_id: The id of the project that this entitlement belongs to.
    """
    __args__ = dict()
    __args__['catalogSourceId'] = catalog_source_id
    __args__['id'] = id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:catalog/getSourceEntitlement:getSourceEntitlement', __args__, opts=opts, typ=GetSourceEntitlementResult).value

    return AwaitableGetSourceEntitlementResult(
        catalog_source_id=__ret__.catalog_source_id,
        definitions=__ret__.definitions,
        id=__ret__.id,
        project_id=__ret__.project_id)


@_utilities.lift_output_func(get_source_entitlement)
def get_source_entitlement_output(catalog_source_id: Optional[pulumi.Input[Optional[str]]] = None,
                                  id: Optional[pulumi.Input[Optional[str]]] = None,
                                  project_id: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSourceEntitlementResult]:
    """
    This data source provides information about a catalog source entitlement in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA catalog source entitlement by its id:

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_entitlement(id=var["catalog_source_entitlement_id"],
        project_id=var["project_id"])
    ```

    This is an example of how to get a vRA catalog source entitlement by its catalog source id:

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_entitlement(catalog_source_id=var["catalog_source_id"],
        project_id=var["project_id"])
    ```


    :param str catalog_source_id: The id of the catalog source to find the entitlement. One of `catalog_source_id` or `id` must be provided.
    :param str id: The id of entitlement. One of `catalog_source_id` or `id` must be provided.
    :param str project_id: The id of the project that this entitlement belongs to.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'LoadBalancerLinkArgs',
    'LoadBalancerNicArgs',
    'LoadBalancerRouteArgs',
    'LoadBalancerRouteHealthCheckConfigurationArgs',
    'LoadBalancerTagArgs',
    'LoadBalancerTargetArgs',
]

@pulumi.input_type
class LoadBalancerLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class LoadBalancerNicArgs:
    def __init__(__self__, *,
                 network_id: pulumi.Input[str],
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 device_index: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "network_id", network_id)
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if device_index is not None:
            pulumi.set(__self__, "device_index", device_index)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "addresses", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="deviceIndex")
    def device_index(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "device_index")

    @device_index.setter
    def device_index(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "device_index", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_group_ids", value)


@pulumi.input_type
class LoadBalancerRouteArgs:
    def __init__(__self__, *,
                 member_port: pulumi.Input[str],
                 member_protocol: pulumi.Input[str],
                 port: pulumi.Input[str],
                 protocol: pulumi.Input[str],
                 health_check_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteHealthCheckConfigurationArgs']]]] = None):
        """
        :param pulumi.Input[str] member_port: Member port where the traffic is routed to.
        :param pulumi.Input[str] member_protocol: The protocol of the member traffic.
        :param pulumi.Input[str] port: Port which the load balancer is listening to.
        :param pulumi.Input[str] protocol: The protocol of the incoming load balancer requests.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteHealthCheckConfigurationArgs']]] health_check_configurations: Load balancer health check configuration.
        """
        pulumi.set(__self__, "member_port", member_port)
        pulumi.set(__self__, "member_protocol", member_protocol)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if health_check_configurations is not None:
            pulumi.set(__self__, "health_check_configurations", health_check_configurations)

    @property
    @pulumi.getter(name="memberPort")
    def member_port(self) -> pulumi.Input[str]:
        """
        Member port where the traffic is routed to.
        """
        return pulumi.get(self, "member_port")

    @member_port.setter
    def member_port(self, value: pulumi.Input[str]):
        pulumi.set(self, "member_port", value)

    @property
    @pulumi.getter(name="memberProtocol")
    def member_protocol(self) -> pulumi.Input[str]:
        """
        The protocol of the member traffic.
        """
        return pulumi.get(self, "member_protocol")

    @member_protocol.setter
    def member_protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "member_protocol", value)

    @property
    @pulumi.getter
    def port(self) -> pulumi.Input[str]:
        """
        Port which the load balancer is listening to.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: pulumi.Input[str]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[str]:
        """
        The protocol of the incoming load balancer requests.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="healthCheckConfigurations")
    def health_check_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteHealthCheckConfigurationArgs']]]]:
        """
        Load balancer health check configuration.
        """
        return pulumi.get(self, "health_check_configurations")

    @health_check_configurations.setter
    def health_check_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerRouteHealthCheckConfigurationArgs']]]]):
        pulumi.set(self, "health_check_configurations", value)


@pulumi.input_type
class LoadBalancerRouteHealthCheckConfigurationArgs:
    def __init__(__self__, *,
                 port: pulumi.Input[str],
                 protocol: pulumi.Input[str],
                 healthy_threshold: Optional[pulumi.Input[int]] = None,
                 interval_seconds: Optional[pulumi.Input[int]] = None,
                 timeout_seconds: Optional[pulumi.Input[int]] = None,
                 unhealthy_threshold: Optional[pulumi.Input[int]] = None,
                 url_path: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] port: Port which the load balancer is listening to.
        :param pulumi.Input[str] protocol: The protocol of the incoming load balancer requests.
        :param pulumi.Input[int] healthy_threshold: Number of consecutive successful checks before considering a particular back-end instance as healthy.
        :param pulumi.Input[int] interval_seconds: Interval (in seconds) at which the health checks will be performed.
        :param pulumi.Input[int] timeout_seconds: Timeout (in seconds) to wait for a response from the back-end instance.
        """
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if healthy_threshold is not None:
            pulumi.set(__self__, "healthy_threshold", healthy_threshold)
        if interval_seconds is not None:
            pulumi.set(__self__, "interval_seconds", interval_seconds)
        if timeout_seconds is not None:
            pulumi.set(__self__, "timeout_seconds", timeout_seconds)
        if unhealthy_threshold is not None:
            pulumi.set(__self__, "unhealthy_threshold", unhealthy_threshold)
        if url_path is not None:
            pulumi.set(__self__, "url_path", url_path)

    @property
    @pulumi.getter
    def port(self) -> pulumi.Input[str]:
        """
        Port which the load balancer is listening to.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: pulumi.Input[str]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[str]:
        """
        The protocol of the incoming load balancer requests.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="healthyThreshold")
    def healthy_threshold(self) -> Optional[pulumi.Input[int]]:
        """
        Number of consecutive successful checks before considering a particular back-end instance as healthy.
        """
        return pulumi.get(self, "healthy_threshold")

    @healthy_threshold.setter
    def healthy_threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthy_threshold", value)

    @property
    @pulumi.getter(name="intervalSeconds")
    def interval_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Interval (in seconds) at which the health checks will be performed.
        """
        return pulumi.get(self, "interval_seconds")

    @interval_seconds.setter
    def interval_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "interval_seconds", value)

    @property
    @pulumi.getter(name="timeoutSeconds")
    def timeout_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Timeout (in seconds) to wait for a response from the back-end instance.
        """
        return pulumi.get(self, "timeout_seconds")

    @timeout_seconds.setter
    def timeout_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "timeout_seconds", value)

    @property
    @pulumi.getter(name="unhealthyThreshold")
    def unhealthy_threshold(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "unhealthy_threshold")

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "unhealthy_threshold", value)

    @property
    @pulumi.getter(name="urlPath")
    def url_path(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "url_path")

    @url_path.setter
    def url_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url_path", value)


@pulumi.input_type
class LoadBalancerTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] key: Tag’s key.
        :param pulumi.Input[str] value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class LoadBalancerTargetArgs:
    def __init__(__self__, *,
                 machine_id: pulumi.Input[str],
                 network_interface_id: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "machine_id", machine_id)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)

    @property
    @pulumi.getter(name="machineId")
    def machine_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "machine_id")

    @machine_id.setter
    def machine_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "machine_id", value)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_interface_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetVersionResult',
    'AwaitableGetVersionResult',
    'get_version',
    'get_version_output',
]

@pulumi.output_type
class GetVersionResult:
    """
    A collection of values returned by getVersion.
    """
    def __init__(__self__, blueprint_description=None, blueprint_id=None, content=None, created_at=None, created_by=None, description=None, id=None, name=None, org_id=None, project_id=None, project_name=None, status=None, updated_at=None, updated_by=None, valid=None, version=None, version_change_log=None):
        if blueprint_description and not isinstance(blueprint_description, str):
            raise TypeError("Expected argument 'blueprint_description' to be a str")
        pulumi.set(__self__, "blueprint_description", blueprint_description)
        if blueprint_id and not isinstance(blueprint_id, str):
            raise TypeError("Expected argument 'blueprint_id' to be a str")
        pulumi.set(__self__, "blueprint_id", blueprint_id)
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if updated_by and not isinstance(updated_by, str):
            raise TypeError("Expected argument 'updated_by' to be a str")
        pulumi.set(__self__, "updated_by", updated_by)
        if valid and not isinstance(valid, str):
            raise TypeError("Expected argument 'valid' to be a str")
        pulumi.set(__self__, "valid", valid)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if version_change_log and not isinstance(version_change_log, str):
            raise TypeError("Expected argument 'version_change_log' to be a str")
        pulumi.set(__self__, "version_change_log", version_change_log)

    @property
    @pulumi.getter(name="blueprintDescription")
    def blueprint_description(self) -> str:
        """
        Description of the cloud template.
        """
        return pulumi.get(self, "blueprint_description")

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> str:
        return pulumi.get(self, "blueprint_id")

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        Blueprint YAML content.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        (Optional) Cloud template version description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the cloud template version.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> str:
        """
        The name of the project the entity belongs to.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Status of the cloud template. Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> str:
        """
        The user the entity was last updated by.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter
    def valid(self) -> str:
        """
        Flag to indicate if the current content of the cloud template is valid.
        """
        return pulumi.get(self, "valid")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        Cloud template version.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="versionChangeLog")
    def version_change_log(self) -> str:
        """
        Cloud template version change log.
        """
        return pulumi.get(self, "version_change_log")


class AwaitableGetVersionResult(GetVersionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVersionResult(
            blueprint_description=self.blueprint_description,
            blueprint_id=self.blueprint_id,
            content=self.content,
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            id=self.id,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            project_name=self.project_name,
            status=self.status,
            updated_at=self.updated_at,
            updated_by=self.updated_by,
            valid=self.valid,
            version=self.version,
            version_change_log=self.version_change_log)


def get_version(blueprint_id: Optional[str] = None,
                id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVersionResult:
    """
    This data source provides information about a cloud template (blueprint) version in vRA.

    ## Example Usage
    ### S

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blueprint.get_version(blueprint_id=var["blueprint_id"],
        id=var["blueprint_version_id"])
    ```


    :param str blueprint_id: Name of the cloud template. One of `id` or `name` must be provided.
    :param str id: The id of the cloud template version.
    """
    __args__ = dict()
    __args__['blueprintId'] = blueprint_id
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:blueprint/getVersion:getVersion', __args__, opts=opts, typ=GetVersionResult).value

    return AwaitableGetVersionResult(
        blueprint_description=__ret__.blueprint_description,
        blueprint_id=__ret__.blueprint_id,
        content=__ret__.content,
        created_at=__ret__.created_at,
        created_by=__ret__.created_by,
        description=__ret__.description,
        id=__ret__.id,
        name=__ret__.name,
        org_id=__ret__.org_id,
        project_id=__ret__.project_id,
        project_name=__ret__.project_name,
        status=__ret__.status,
        updated_at=__ret__.updated_at,
        updated_by=__ret__.updated_by,
        valid=__ret__.valid,
        version=__ret__.version,
        version_change_log=__ret__.version_change_log)


@_utilities.lift_output_func(get_version)
def get_version_output(blueprint_id: Optional[pulumi.Input[str]] = None,
                       id: Optional[pulumi.Input[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVersionResult]:
    """
    This data source provides information about a cloud template (blueprint) version in vRA.

    ## Example Usage
    ### S

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.blueprint.get_version(blueprint_id=var["blueprint_id"],
        id=var["blueprint_version_id"])
    ```


    :param str blueprint_id: Name of the cloud template. One of `id` or `name` must be provided.
    :param str id: The id of the cloud template version.
    """
    ...
